@@ -8,7 +8,7 @@ use Regexp::RegGrp;
 
 # -----------------------------------------------------------------------------
 
-our $VERSION = '1.003_001';
+our $VERSION = '1.002';
 
 our @BOOLEAN_ACCESSORS = (
     'remove_comments',
@@ -30,13 +30,13 @@ our @SAVE_SPACE_ELEMENTS = (
 );
 
 our @VOID_ELEMENTS = (
-    'area', 'base', 'br', 'col', 'command', 'embed', 'hr', 'img', 'input',
-    'keygen', 'link', 'meta', 'param', 'source', 'track', 'wbr'
+        'area', 'base', 'br', 'col', 'command', 'embed', 'hr', 'img', 'input',
+        'keygen', 'link', 'meta', 'param', 'source', 'track', 'wbr'
 );
 
 # Some regular expressions are from HTML::Clean
 
-our $COMMENT        = '((?>\s*))(<!--(?:(?![#\[]| google_ad_section_).*?)?-->)((?>\s*))';
+our $COMMENT        = '((?>\s*))(<!--(?:(?:[^#\[]|(?! google_ad_section_)).*?)?-->)((?>\s*))';
 
 our $PACKER_COMMENT = '<!--\s*HTML::Packer\s*(\w+)\s*-->';
 
@@ -59,7 +59,7 @@ our $WHITESPACES    = [
         modifier    => 'm'
     },
     {
-        regexp      => '[^\S\n]*$',
+        regexp      => '\s*$',
         replacement => '',
         modifier    => 'm'
     },
@@ -236,10 +236,9 @@ sub init {
                 my ( $opening, undef, $content, $closing )  = @{$_[0]->{submatches}};
 
                 if ( $content ) {
-                    my $opening_script_re   = '<\s*script' . ( $self->html5() ? '[^>]*>' : '[^>]*(?:java|ecma)script[^>]*>' );
-                    my $opening_style_re    = '<\s*style' . ( $self->html5() ? '[^>]*>' : '[^>]*text\/css[^>]*>' );
+                    my $opening_re = '<\s*script' . ( $self->html5() ? '[^>]*>' : '[^>]*(?:java|ecma)script[^>]*>' );
 
-                    if ( $opening =~ /$opening_script_re/i ) {
+                    if ( $opening =~ /$opening_re/i ) {
                         $opening =~ s/ type="(text\/)?(java|ecma)script"//i if ( $self->html5() );
 
                         if ( $self->javascript_packer() and $self->do_javascript() ) {
@@ -250,9 +249,7 @@ sub init {
                             }
                         }
                     }
-                    elsif ( $opening =~ /$opening_style_re/i ) {
-                        $opening =~ s/ type="text\/css"//i if ( $self->html5() );
-
+                    elsif ( $opening =~ /<\s*style[^>]*text\/css[^>]*>/ ) {
                         if ( $self->css_packer() and $self->do_stylesheet() ) {
                             $self->css_packer()->minify( \$content, { compress => $self->do_stylesheet() } );
                             $content = "\n" . $content if ( $self->do_stylesheet() eq 'pretty' );
@@ -282,9 +279,9 @@ sub init {
         }
     ];
 
-    foreach ( @HTML::Packer::REGGRPS ) {
+    map {
         $self->{ '_reggrp_' . $_ } = Regexp::RegGrp->new( { reggrp => $self->{$_}->{reggrp_data} } );
-    }
+    } @REGGRPS;
 
     $self->{ '_reggrp_' . $GLOBAL_REGGRP } = Regexp::RegGrp->new(
         {
@@ -408,7 +405,7 @@ HTML::Packer - Another HTML code cleaner
 
 =head1 VERSION
 
-Version 1.003_001
+Version 1.002
 
 =head1 DESCRIPTION
 
